Index: /trunk/include/iprt/asm-amd64-x86.h
===================================================================
--- /trunk/include/iprt/asm-amd64-x86.h	(revision 57925)
+++ /trunk/include/iprt/asm-amd64-x86.h	(revision 57926)
@@ -262,5 +262,5 @@
 /**
  * Sets the content of the GDTR CPU register.
- * @param   pIdtr   Where to load the GDTR contents from
+ * @param   pGdtr   Where to load the GDTR contents from
  */
 #if RT_INLINE_ASM_EXTERNAL
Index: /trunk/include/iprt/asm.h
===================================================================
--- /trunk/include/iprt/asm.h	(revision 57925)
+++ /trunk/include/iprt/asm.h	(revision 57926)
@@ -133,5 +133,5 @@
 #endif
 
-/** @def RT_INLINE_DONT_USE_CMPXCHG8B
+/** @def RT_INLINE_DONT_MIX_CMPXCHG8B_AND_PIC
  * i686-apple-darwin9-gcc-4.0.1 (GCC) 4.0.1 (Apple Inc. build 5493) screws up
  * RTSemRWRequestWrite semsemrw-lockless-generic.cpp in release builds. PIC
Index: /trunk/include/iprt/asn1.h
===================================================================
--- /trunk/include/iprt/asn1.h	(revision 57925)
+++ /trunk/include/iprt/asn1.h	(revision 57926)
@@ -291,5 +291,5 @@
  * @param   pThisCore       Pointer to the ASN.1 core of the object to check out.
  * @param   fFlags          See RTASN1_CHECK_SANITY_F_XXX.
- * @param   pszErrInfo      Where to return additional error details. Optional.
+ * @param   pErrInfo        Where to return additional error details. Optional.
  * @param   pszErrorTag     Tag for the additional error details.
  */
@@ -772,5 +772,5 @@
  * Initializes an interger object to a default value.
  * @returns VINF_SUCCESS.
- * @param   pBoolean            The integer object representation.
+ * @param   pInteger            The integer object representation.
  * @param   uValue              The default value (unsigned 64-bit).
  * @param   pAllocator          The allocator (pro forma).
@@ -1350,5 +1350,5 @@
  * Calls the destructor of the ASN.1 object.
  *
- * @param   pAsn1Core           The IPRT representation of an ASN.1 object.
+ * @param   pThisCore           The IPRT representation of an ASN.1 object.
  */
 RTDECL(void) RTAsn1VtDelete(PRTASN1CORE pThisCore);
@@ -1400,5 +1400,5 @@
  * @param   pThisCore       Pointer to the ASN.1 core of the object to check out.
  * @param   fFlags          See RTASN1_CHECK_SANITY_F_XXX.
- * @param   pszErrInfo      Where to return additional error details. Optional.
+ * @param   pErrInfo        Where to return additional error details. Optional.
  * @param   pszErrorTag     Tag for the additional error details.
  */
@@ -1586,5 +1586,5 @@
  * @returns Pointer to the allocator info (for call in alloc parameter).
  * @param   pCursor             The cursor.
- * @param   pAllocator          The allocation structure to initialize.
+ * @param   pAllocation         The allocation structure to initialize.
  */
 RTDECL(PRTASN1ALLOCATION) RTAsn1CursorInitAllocation(PRTASN1CURSOR pCursor, PRTASN1ALLOCATION pAllocation);
@@ -1925,5 +1925,6 @@
  * @param   pCursor             The cursor we're decoding from.
  * @param   fFlags              RTASN1CURSOR_GET_F_XXX.
- * @param   pCtxTagCore         The output context tag object.
+ * @param   uExpectedTag        The expected tag.
+ * @param   pCtxTag             The output context tag object.
  * @param   pCtxTagCursor       The output cursor for the context tag content.
  * @param   pszErrorTag         Error tag, this will be associated with the
Index: /trunk/include/iprt/assert.h
===================================================================
--- /trunk/include/iprt/assert.h	(revision 57925)
+++ /trunk/include/iprt/assert.h	(revision 57926)
@@ -1590,5 +1590,5 @@
     } while (0)
 
-/** @def AssertLogRelMsgFailedReturn
+/** @def AssertLogRelMsgFailedReturnStmt
  * An assertion failed, execute @a stmt and return @a rc.
  * Strict builds will hit a breakpoint, non-strict will only do LogRel.
@@ -1622,5 +1622,5 @@
     } while (0)
 
-/** @def AssertLogRelMsgFailedReturnVoid
+/** @def AssertLogRelMsgFailedReturnVoidStmt
  * An assertion failed, execute @a stmt and return void.
  * Strict builds will hit a breakpoint, non-strict will only do LogRel.
@@ -2096,5 +2096,5 @@
 #define AssertRCReturn(rc, rcRet)   AssertMsgRCReturn(rc, ("%Rra\n", (rc)), rcRet)
 
-/** @def AssertRCReturn
+/** @def AssertRCReturnStmt
  * Asserts a iprt status code successful, bitch (RT_STRICT mode only), execute
  * @a stmt and returns @a rcRet if it isn't.
@@ -2116,5 +2116,5 @@
 #define AssertRCReturnVoid(rc)      AssertMsgRCReturnVoid(rc, ("%Rra\n", (rc)))
 
-/** @def AssertReturnVoidStmt
+/** @def AssertRCReturnVoidStmt
  * Asserts a iprt status code successful, bitch (RT_STRICT mode only), and
  * execute the given statement/return if it isn't.
Index: /trunk/include/iprt/cdefs.h
===================================================================
--- /trunk/include/iprt/cdefs.h	(revision 57925)
+++ /trunk/include/iprt/cdefs.h	(revision 57926)
@@ -59,4 +59,6 @@
 # define RT_ARCH_AMD64
 # define RT_ARCH_X86
+# define RT_ARCH_SPARC
+# define RT_ARCH_SPARC64
 # define IN_RING0
 # define IN_RING3
@@ -73,5 +75,5 @@
 # define RT_LOCK_STRICT_ORDER
 # define RT_LOCK_NO_STRICT_ORDER
-# define Breakpoint
+# define RT_BREAKPOINT
 # define RT_NO_DEPRECATED_MACROS
 # define RT_EXCEPTIONS_ENABLED
@@ -81,4 +83,6 @@
 # define RT_COMPILER_WITH_80BIT_LONG_DOUBLE
 # define RT_NO_VISIBILITY_HIDDEN
+# define RT_GCC_SUPPORTS_VISIBILITY_HIDDEN
+# define RT_COMPILER_SUPPORTS_LAMBDA
 #endif /* DOXYGEN_RUNNING */
 
@@ -339,5 +343,5 @@
  */
 #ifndef RT_OPSYS
-# if defined(RT_OS_UNKNOWN)
+# if defined(RT_OS_UNKNOWN) || defined(DOXYGEN_RUNNING)
 #  define RT_OPSYS RT_OPSYS_UNKNOWN
 # elif defined(RT_OS_AGNOSTIC)
@@ -1426,5 +1430,5 @@
 #define RT_CONCAT_HLP(a,b)          a##b
 
-/** @def RT_CONCAT
+/** @def RT_CONCAT3
  * Concatenate the expanded arguments without any extra spaces in between.
  *
@@ -1437,5 +1441,5 @@
 #define RT_CONCAT3_HLP(a,b,c)       a##b##c
 
-/** @def RT_CONCAT
+/** @def RT_CONCAT4
  * Concatenate the expanded arguments without any extra spaces in between.
  *
Index: /trunk/include/iprt/cdrom.h
===================================================================
--- /trunk/include/iprt/cdrom.h	(revision 57925)
+++ /trunk/include/iprt/cdrom.h	(revision 57926)
@@ -64,5 +64,5 @@
  * @param   phCdrom             Where to return the CDROM handle.
  */
-RTDECL(int)         RTCdromOpen(const char *psz, uint32_t fFlags, PRTCDROM phCdrom);
+RTDECL(int)         RTCdromOpen(const char *pszName, uint32_t fFlags, PRTCDROM phCdrom);
 
 /**
@@ -166,5 +166,5 @@
  *
  * @returns IPRT status code.
- * @param   pszName             The CD-ROM name (path).
+ * @param   iCdrom              The CD-ROM number.
  * @param   fFlags              Open flags, see RTCDROM_O_XXX.
  * @param   phCdrom             Where to return the CDROM handle .
Index: /trunk/include/iprt/condvar.h
===================================================================
--- /trunk/include/iprt/condvar.h	(revision 57925)
+++ /trunk/include/iprt/condvar.h	(revision 57926)
@@ -54,5 +54,5 @@
  *                              condition variable.
  */
-RTDECL(int)  RTConvVarCreate(PRTCONDVAR phCondVar);
+RTDECL(int)  RTCondVarCreate(PRTCONDVAR phCondVar);
 
 /**
@@ -72,8 +72,8 @@
  * @param   ...                 Format string arguments.
  */
-RTDECL(int)  RTConvVarCreateEx(PRTCONDVAR phCondVar, uint32_t fFlags, RTLOCKVALCLASS hClass,
+RTDECL(int)  RTCondVarCreateEx(PRTCONDVAR phCondVar, uint32_t fFlags, RTLOCKVALCLASS hClass,
                                const char *pszNameFmt, ...) RT_IPRT_FORMAT_ATTR(4, 5);
 
-/** @name RTConvVarCreateEx flags
+/** @name RTCondVarCreateEx flags
  * @{ */
 /** Disables lock validation. */
@@ -88,5 +88,5 @@
  *                              is quietly ignored (VINF_SUCCESS).
  */
-RTDECL(int)  RTConvVarDestroy(RTCONDVAR hCondVar);
+RTDECL(int)  RTCondVarDestroy(RTCONDVAR hCondVar);
 
 /**
@@ -100,7 +100,7 @@
  *
  * @returns iprt status code.
- * @param   hConvVar            The condition variable to signal.
- */
-RTDECL(int)  RTConvVarSignal(RTCONDVAR hCondVar);
+ * @param   hCondVar            The condition variable to signal.
+ */
+RTDECL(int)  RTCondVarSignal(RTCONDVAR hCondVar);
 
 /**
@@ -114,17 +114,17 @@
  *
  * @returns iprt status code.
- * @param   hConvVar            The condition variable to broadcast.
- */
-RTDECL(int)  RTConvVarBroadcast(RTCONDVAR hCondVar);
-
-/**
- * Wait for the condition variable to be signaled, resume on interruption.
- *
- * This function will resume if the wait is interrupted by an async system event
- * (like a unix signal) or similar.
- *
- * @returns iprt status code.
- *          Will not return VERR_INTERRUPTED.
- * @param   hConvVar            The condition variable to wait on.
+ * @param   hCondVar            The condition variable to broadcast.
+ */
+RTDECL(int)  RTCondVarBroadcast(RTCONDVAR hCondVar);
+
+/**
+ * Wait for the condition variable to be signaled, resume on interruption.
+ *
+ * This function will resume if the wait is interrupted by an async system event
+ * (like a unix signal) or similar.
+ *
+ * @returns iprt status code.
+ *          Will not return VERR_INTERRUPTED.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hMtx                The mutex to leave during the wait and which
  *                              will be re-enter before returning.
@@ -132,13 +132,13 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarMutexWait(RTCONDVAR hCondVar, RTSEMMUTEX hMtx, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, return on interruption.
- *
- * This function will not resume the wait if interrupted.
- *
- * @returns iprt status code.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarMutexWait(RTCONDVAR hCondVar, RTSEMMUTEX hMtx, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, return on interruption.
+ *
+ * This function will not resume the wait if interrupted.
+ *
+ * @returns iprt status code.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hMtx                The mutex to leave during the wait and which
  *                              will be re-enter before returning.
@@ -146,15 +146,15 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarMutexWaitNoResume(RTCONDVAR hCondVar, RTSEMMUTEX hMtx, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, resume on interruption.
- *
- * This function will resume if the wait is interrupted by an async system event
- * (like a unix signal) or similar.
- *
- * @returns iprt status code.
- *          Will not return VERR_INTERRUPTED.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarMutexWaitNoResume(RTCONDVAR hCondVar, RTSEMMUTEX hMtx, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, resume on interruption.
+ *
+ * This function will resume if the wait is interrupted by an async system event
+ * (like a unix signal) or similar.
+ *
+ * @returns iprt status code.
+ *          Will not return VERR_INTERRUPTED.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hRWSem              The read/write semaphore to write-leave during
  *                              the wait and which will be re-enter in write
@@ -163,13 +163,13 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarRWWriteWait(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, return on interruption.
- *
- * This function will not resume the wait if interrupted.
- *
- * @returns iprt status code.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarRWWriteWait(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, return on interruption.
+ *
+ * This function will not resume the wait if interrupted.
+ *
+ * @returns iprt status code.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hRWSem              The read/write semaphore to write-leave during
  *                              the wait and which will be re-enter in write
@@ -178,15 +178,15 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarRWWriteWaitNoResume(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, resume on interruption.
- *
- * This function will resume if the wait is interrupted by an async system event
- * (like a unix signal) or similar.
- *
- * @returns iprt status code.
- *          Will not return VERR_INTERRUPTED.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarRWWriteWaitNoResume(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, resume on interruption.
+ *
+ * This function will resume if the wait is interrupted by an async system event
+ * (like a unix signal) or similar.
+ *
+ * @returns iprt status code.
+ *          Will not return VERR_INTERRUPTED.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hRWSem              The read/write semaphore to read-leave during
  *                              the wait and which will be re-enter in read mode
@@ -195,13 +195,13 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarRWReadWait(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, return on interruption.
- *
- * This function will not resume the wait if interrupted.
- *
- * @returns iprt status code.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarRWReadWait(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, return on interruption.
+ *
+ * This function will not resume the wait if interrupted.
+ *
+ * @returns iprt status code.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   hRWSem              The read/write semaphore to read-leave during
  *                              the wait and which will be re-enter in read mode
@@ -210,15 +210,15 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarRWReadWaitNoResume(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, resume on interruption.
- *
- * This function will resume if the wait is interrupted by an async system event
- * (like a unix signal) or similar.
- *
- * @returns iprt status code.
- *          Will not return VERR_INTERRUPTED.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarRWReadWaitNoResume(RTCONDVAR hCondVar, RTSEMRW hRWSem, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, resume on interruption.
+ *
+ * This function will resume if the wait is interrupted by an async system event
+ * (like a unix signal) or similar.
+ *
+ * @returns iprt status code.
+ *          Will not return VERR_INTERRUPTED.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   pCritSect           The critical section to leave during the wait
  *                              and which will be re-enter before returning.
@@ -226,13 +226,13 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarCritSectWait(RTCONDVAR hCondVar, PRTCRITSECT pCritSect, RTMSINTERVAL cMillies);
-
-/**
- * Wait for the condition variable to be signaled, return on interruption.
- *
- * This function will not resume the wait if interrupted.
- *
- * @returns iprt status code.
- * @param   hConvVar            The condition variable to wait on.
+RTDECL(int)  RTCondVarCritSectWait(RTCONDVAR hCondVar, PRTCRITSECT pCritSect, RTMSINTERVAL cMillies);
+
+/**
+ * Wait for the condition variable to be signaled, return on interruption.
+ *
+ * This function will not resume the wait if interrupted.
+ *
+ * @returns iprt status code.
+ * @param   hCondVar            The condition variable to wait on.
  * @param   pCritSect           The critical section to leave during the wait
  *                              and which will be re-enter before returning.
@@ -240,5 +240,5 @@
  *                              RT_INDEFINITE_WAIT to wait forever.
  */
-RTDECL(int)  RTConvVarCritSectWaitNoResume(RTCONDVAR hCondVar, PRTCRITSECT pCritSect, RTMSINTERVAL cMillies);
+RTDECL(int)  RTCondVarCritSectWaitNoResume(RTCONDVAR hCondVar, PRTCRITSECT pCritSect, RTMSINTERVAL cMillies);
 
 /**
@@ -246,13 +246,13 @@
  *
  * This is only used for validating usage and deadlock detection.  When used
- * after calls to RTConvVarAddSignaller, the specified thread will be the only
+ * after calls to RTCondVarAddSignaller, the specified thread will be the only
  * signalling thread.
  *
- * @param   hConvVar            The condition variable.
+ * @param   hCondVar            The condition variable.
  * @param   hThread             The thread that will signal it.  Pass
  *                              NIL_RTTHREAD to indicate that there is no
  *                              special signalling thread.
  */
-RTDECL(void) RTConvVarSetSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
+RTDECL(void) RTCondVarSetSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
 
 /**
@@ -261,9 +261,9 @@
  * First call RTCondVarSetSignaller then add further threads with this.
  *
- * @param   hConvVar            The condition variable.
+ * @param   hCondVar            The condition variable.
  * @param   hThread             The thread that will signal it. NIL_RTTHREAD is
  *                              not accepted.
  */
-RTDECL(void) RTConvVarAddSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
+RTDECL(void) RTCondVarAddSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
 
 /**
@@ -272,8 +272,8 @@
  * Reverts work done by RTCondVarAddSignaller and RTCondVarSetSignaller.
  *
- * @param   hConvVar            The condition variable.
+ * @param   hCondVar            The condition variable.
  * @param   hThread             A previously added thread.
  */
-RTDECL(void) RTConvVarRemoveSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
+RTDECL(void) RTCondVarRemoveSignaller(RTCONDVAR hCondVar, RTTHREAD hThread);
 
 /** @} */
Index: /trunk/include/iprt/coredumper.h
===================================================================
--- /trunk/include/iprt/coredumper.h	(revision 57925)
+++ /trunk/include/iprt/coredumper.h	(revision 57926)
@@ -73,6 +73,4 @@
  * @param   pszOutputDir        The directory to store the cores in.  If NULL
  *                              the current directory will be used.
- * @param   pszBaseName         Base file name, no directory.  If NULL the
- *                              dumper will generate an appropriate name.
  * @param   fFlags              Setup flags, 0 in NOT a valid flag, it must be
  *                              one or more of RTCOREDUMPER_FLAGS_*.
Index: /trunk/include/iprt/critsect.h
===================================================================
--- /trunk/include/iprt/critsect.h	(revision 57925)
+++ /trunk/include/iprt/critsect.h	(revision 57926)
@@ -175,7 +175,6 @@
  * @param   pCritSect       The critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectEnterDebug(PRTCRITSECT pCritSect, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -205,7 +204,6 @@
  * @param   pCritSect       The critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectTryEnterDebug(PRTCRITSECT pCritSect, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -244,7 +242,6 @@
  * @param   papCritSects    Array of critical section pointers.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  *
  * @remark  See RTCritSectEnterMultiple().
@@ -525,7 +522,6 @@
  * @param   pThis           Pointer to the read/write critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectRwEnterSharedDebug(PRTCRITSECTRW pThis, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -557,7 +553,6 @@
  * @param   pThis           Pointer to the read/write critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectRwTryEnterSharedDebug(PRTCRITSECTRW pThis, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -594,7 +589,6 @@
  * @param   pThis           Pointer to the read/write critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectRwEnterExclDebug(PRTCRITSECTRW pThis, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -626,7 +620,6 @@
  * @param   pThis           Pointer to the read/write critical section.
  * @param   uId             Where we're entering the section.
- * @param   pszFile         The source position - file.
- * @param   iLine           The source position - line.
- * @param   pszFunction     The source position - function.
+ * @param   SRC_POS         The source position where call is being made from.
+ *                          Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int) RTCritSectRwTryEnterExclDebug(PRTCRITSECTRW pThis, RTHCUINTPTR uId, RT_SRC_POS_DECL);
Index: /trunk/include/iprt/file.h
===================================================================
--- /trunk/include/iprt/file.h	(revision 57925)
+++ /trunk/include/iprt/file.h	(revision 57926)
@@ -781,14 +781,18 @@
  * Opens a new file with a unique name in the temp directory.
  *
- * @returns iprt status code.
- * @param   pszTemplate     The file name template on input. The actual file
- *                          name on success. Empty string on failure.
- * @param   fMode           The mode to create the file with.  Use 0600 unless
- *                          you have reason not to.
+ * Unlike the other temp file creation APIs, this does not allow you any control
+ * over the name.  Nor do you have to figure out where the temporary directory
+ * is.
+ *
+ * @returns iprt status code.
+ * @param   phFile          Where to return the handle to the file.
+ * @param   pszFilename     Where to return the name (+path) of the file .
+ * @param   cbFilename      The size of the buffer @a pszFilename points to.
+ * @param   fOpen           The RTFILE_O_XXX flags to open the file with.
  *
  * @remarks If actual control over the filename or location is required, we'll
  *          create an extended edition of this API.
  */
-RTDECL(int) RTFileOpenTemp(PRTFILE pFile, char *pszFilename, size_t cbFilename, uint64_t fOpen);
+RTDECL(int) RTFileOpenTemp(PRTFILE phFile, char *pszFilename, size_t cbFilename, uint64_t fOpen);
 
 
@@ -1005,5 +1009,5 @@
  * @returns iprt status code.
  * @param   File        Handle to the file.
- * @param   iRequest    IOCTL request to carry out.
+ * @param   ulRequest   IOCTL request to carry out.
  * @param   pvData      IOCTL data.
  * @param   cbData      Size of the IOCTL data.
Index: /trunk/include/iprt/http.h
===================================================================
--- /trunk/include/iprt/http.h	(revision 57925)
+++ /trunk/include/iprt/http.h	(revision 57926)
@@ -164,8 +164,11 @@
  *
  * @param   hHttp           The HTTP client instance.
- * @param   pszProxy        URL of the proxy.
+ * @param   pszProxyUrl     URL of the proxy server.
  * @param   uPort           port number of the proxy, use 0 for not specifying a port.
  * @param   pszProxyUser    Username, pass NULL for no authentication.
  * @param   pszProxyPwd     Password, pass NULL for no authentication.
+ *
+ * @todo    This API does not allow specifying the type of proxy server... We're
+ *          currently assuming it's a HTTP proxy.
  */
 RTR3DECL(int) RTHttpSetProxy(RTHTTP hHttp, const char *pszProxyUrl, uint32_t uPort,
Index: /trunk/include/iprt/initterm.h
===================================================================
--- /trunk/include/iprt/initterm.h	(revision 57925)
+++ /trunk/include/iprt/initterm.h	(revision 57926)
@@ -77,5 +77,5 @@
  * @param   fFlags          Flags, see RTR3INIT_XXX.
  */
-RTR3DECL(int) RTR3InitExe(int cArgs, char ***papszArgs, uint32_t fFlags);
+RTR3DECL(int) RTR3InitExe(int cArgs, char ***ppapszArgs, uint32_t fFlags);
 
 /**
@@ -101,5 +101,5 @@
  *                          out ourselves.
  */
-RTR3DECL(int) RTR3InitEx(uint32_t iVersion, uint32_t fFlags, int cArgs, char ***papszArgs, const char *pszProgramPath);
+RTR3DECL(int) RTR3InitEx(uint32_t iVersion, uint32_t fFlags, int cArgs, char ***ppapszArgs, const char *pszProgramPath);
 
 /**
Index: /trunk/include/iprt/ldr.h
===================================================================
--- /trunk/include/iprt/ldr.h	(revision 57925)
+++ /trunk/include/iprt/ldr.h	(revision 57926)
@@ -690,5 +690,5 @@
     /** Watcom debug info. */
     RTLDRDBGINFOTYPE_WATCOM,
-    /** IBM High Level Language debug info.. */
+    /** IBM High Level Language debug info. */
     RTLDRDBGINFOTYPE_HLL,
     /** The end of the valid debug info values (exclusive). */
@@ -931,19 +931,19 @@
  *
  * @param   hLdrMod         The module handle.
+ * @param   Rva             The segment index.
+ * @param   offSeg          The segment offset.
+ * @param   pRva            Where to return the RVA.
+ */
+RTDECL(int) RTLdrSegOffsetToRva(RTLDRMOD hLdrMod, uint32_t iSeg, RTLDRADDR offSeg, PRTLDRADDR pRva);
+
+/**
+ * Converts a segment:offset into an image relative virtual address (RVA).
+ *
+ * @returns IPRT status code.
+ *
+ * @param   hLdrMod         The module handle.
  * @param   Rva             The link address to convert.
  * @param   piSeg           Where to return the segment index.
  * @param   poffSeg         Where to return the segment offset.
- */
-RTDECL(int) RTLdrSegOffsetToRva(RTLDRMOD hLdrMod, uint32_t iSeg, RTLDRADDR offSeg, PRTLDRADDR pRva);
-
-/**
- * Converts a segment:offset into an image relative virtual address (RVA).
- *
- * @returns IPRT status code.
- *
- * @param   hLdrMod         The module handle.
- * @param   iSeg            The segment index.
- * @param   offSeg          The segment offset.
- * @param   pRva            Where to return the RVA.
  */
 RTDECL(int) RTLdrRvaToSegOffset(RTLDRMOD hLdrMod, RTLDRADDR Rva, uint32_t *piSeg, PRTLDRADDR poffSeg);
@@ -1036,5 +1036,5 @@
  *
  * @param   hLdrMod         The module handle.
- * @param   enmLdrProp      The property to query.
+ * @param   enmProp         The property to query.
  * @param   pvBuf           Pointer to the input / output buffer.  In most cases
  *                          it's only used for returning data.
@@ -1059,5 +1059,5 @@
  *
  * @param   hLdrMod         The module handle.
- * @param   enmLdrProp      The property to query.
+ * @param   enmProp         The property to query.
  * @param   pvBits          Optional pointer to bits returned by
  *                          RTLdrGetBits().  This can be utilized by some module
Index: /trunk/include/iprt/list-off32.h
===================================================================
--- /trunk/include/iprt/list-off32.h	(revision 57925)
+++ /trunk/include/iprt/list-off32.h	(revision 57926)
@@ -233,5 +233,5 @@
  *
  * @param   pList               The list.
- * @param   pNodeStruct         The node structure to check.  Typically
+ * @param   pNode               The node structure to check.  Typically
  *                              something obtained from RTListOff32NodeGetNext()
  *                              or RTListOff32NodeGetPrev().  This is NOT a
Index: /trunk/include/iprt/list.h
===================================================================
--- /trunk/include/iprt/list.h	(revision 57925)
+++ /trunk/include/iprt/list.h	(revision 57926)
@@ -179,5 +179,5 @@
  *
  * @param   pList               The list.
- * @param   pNodeStruct         The node structure to check.  Typically
+ * @param   pNode               The node structure to check.  Typically
  *                              something obtained from RTListNodeGetNext() or
  *                              RTListNodeGetPrev().  This is NOT a PRTLISTNODE
Index: /trunk/include/iprt/lockvalidator.h
===================================================================
--- /trunk/include/iprt/lockvalidator.h	(revision 57925)
+++ /trunk/include/iprt/lockvalidator.h	(revision 57926)
@@ -694,4 +694,5 @@
  *                              pass NIL_RTTHREAD and we'll figure it out.
  * @param   pSrcPos             The source position of the lock operation.
+ * @param   cMillies            Intended sleep time in milliseconds.
  */
 RTDECL(int)  RTLockValidatorRecSharedCheckOrder(PRTLOCKVALRECSHRD pRec, RTTHREAD hThreadSelf,
@@ -716,4 +717,5 @@
  * @param   pSrcPos             The source position of the lock operation.
  * @param   fRecursiveOk        Whether it's ok to recurse.
+ * @param   cMillies            Intended sleep time in milliseconds.
  * @param   enmSleepState       The sleep state to enter on successful return.
  * @param   fReallySleeping     Is it really going to sleep now or not.  Use
@@ -734,4 +736,5 @@
  * @param   pSrcPos             The source position of the lock operation.
  * @param   fRecursiveOk        Whether it's ok to recurse.
+ * @param   cMillies            Intended sleep time in milliseconds.
  * @param   enmSleepState       The sleep state to enter on successful return.
  * @param   fReallySleeping     Is it really going to sleep now or not.  Use
@@ -988,7 +991,6 @@
  *                              itself new locking order rules (true), or if the
  *                              user will teach it all it needs to know (false).
- * @param   pszFile             The source position of the call, file.
- * @param   iLine               The source position of the call, line.
- * @param   pszFunction         The source position of the call, function.
+ * @param   SRC_POS             The source position where call is being made from.
+ *                              Use RT_SRC_POS when possible.  Optional.
  * @param   pszNameFmt          Class name format string, optional (NULL).  Max
  *                              length is 32 bytes.
@@ -1007,7 +1009,6 @@
  *          first retainer.  NIL_RTLOCKVALCLASS if we run into trouble.
  *
- * @param   pszFile             The source position of the call, file.
- * @param   iLine               The source position of the call, line.
- * @param   pszFunction         The source position of the call, function.
+ * @param   SRC_POS             The source position where call is being made from.
+ *                              Use RT_SRC_POS when possible.  Optional.
  * @param   pszNameFmt          Class name format string, optional (NULL).  Max
  *                              length is 32 bytes.
@@ -1029,7 +1030,6 @@
  *
  * @returns Class handle (not retained!) or NIL_RTLOCKVALCLASS.
- * @param   pszFile             The source file.
- * @param   iLine               The line in that source file.
- * @param   pszFunction         The function name.
+ * @param   SRC_POS             The source position where call is being made from.
+ *                              Use RT_SRC_POS when possible.  Optional.
  * @param   pszNameFmt          Class name format string, optional (NULL).  Max
  *                              length is 32 bytes.
@@ -1058,5 +1058,5 @@
 /**
  * Teaches the class @a hClass that locks in the class @a hPriorClass can be
- * held when taking a lock of class @hClass
+ * held when taking a lock of class @a hClass
  *
  * @returns IPRT status.
@@ -1073,5 +1073,5 @@
  * @returns IPRT status.
  * @param   hClass              Handle to the class to change.
- * @param   fEnable             Enable it (true) or disable it (false).
+ * @param   fEnabled            Enable it (true) or disable it (false).
  */
 RTDECL(int) RTLockValidatorClassEnforceStrictReleaseOrder(RTLOCKVALCLASS hClass, bool fEnabled);
Index: /trunk/include/iprt/log.h
===================================================================
--- /trunk/include/iprt/log.h	(revision 57925)
+++ /trunk/include/iprt/log.h	(revision 57926)
@@ -1104,5 +1104,5 @@
  * @{ */
 
-/** @def LogWarning1
+/** @def Log1Warning
  * The same as Log(), but prepents a <tt>"WARNING! "</tt> string to the message.
  *
@@ -1115,5 +1115,5 @@
 #endif
 
-/** @def LogWarningFunc
+/** @def Log1WarningFunc
  * The same as LogWarning(), but prepents the log message with the function name.
  *
@@ -1128,5 +1128,5 @@
 #endif
 
-/** @def LogWarningThisFunc
+/** @def Log1WarningThisFunc
  * The same as LogWarningFunc() but for class functions (methods): the resulting
  * log line is additionally prepended with a hex value of |this| pointer.
Index: /trunk/include/iprt/manifest.h
===================================================================
--- /trunk/include/iprt/manifest.h	(revision 57925)
+++ /trunk/include/iprt/manifest.h	(revision 57926)
@@ -114,5 +114,5 @@
  */
 RTDECL(int) RTManifestEqualsEx(RTMANIFEST hManifest1, RTMANIFEST hManifest2, const char * const *papszIgnoreEntries,
-                               const char * const *papszIgnoreAttr, uint32_t fFlags, char *pszError, size_t cbError);
+                               const char * const *papszIgnoreAttrs, uint32_t fFlags, char *pszError, size_t cbError);
 
 /** @defgroup RTMANIFEST_EQUALS_XXX     RTManifestEqualsEx flags
@@ -164,9 +164,64 @@
 
 /**
- * Query a manifest entry attribute.
+ * Query a manifest attribute.
  *
  * @returns IPRT status code.
  * @retval  VERR_BUFFER_OVERFLOW if the value buffer is too small. The @a
  *          pszValue buffer will not be modified.
+ * @retval  VERR_MANIFEST_ATTR_NOT_FOUND
+ * @retval  VERR_MANIFEST_ATTR_TYPE_NOT_FOUND
+ * @retval  VERR_MANIFEST_ATTR_TYPE_MISMATCH
+ *
+ * @param   hManifest           The manifest handle.
+ * @param   pszAttr             The attribute name.  If NULL, it will be
+ *                              selected by @a fType alone.
+ * @param   fType               The attribute types the entry should match. Pass
+ *                              Pass RTMANIFEST_ATTR_ANY match any.  If more
+ *                              than one is given, the first matching one is
+ *                              returned.
+ * @param   pszValue            Where to return value.
+ * @param   cbValue             The size of the buffer @a pszValue points to.
+ * @param   pfType              Where to return the attribute type value.
+ */
+RTDECL(int) RTManifestQueryAttr(RTMANIFEST hManifest, const char *pszAttr, uint32_t fType,
+                                char *pszValue, size_t cbValue, uint32_t *pfType);
+
+/**
+ * Sets an attribute of a manifest entry.
+ *
+ * @returns IPRT status code.
+ * @param   hManifest           The manifest handle.
+ * @param   pszEntry            The entry name.  This will automatically be
+ *                              added if there was no previous call to
+ *                              RTManifestEntryAdd for this name.  See
+ *                              RTManifestEntryAdd for the entry name rules.
+ * @param   pszAttr             The attribute name.  If this already exists,
+ *                              its value will be replaced.
+ * @param   pszValue            The value string.
+ * @param   fType               The attribute type, pass
+ *                              RTMANIFEST_ATTR_UNKNOWN if not known.
+ */
+RTDECL(int) RTManifestEntrySetAttr(RTMANIFEST hManifest, const char *pszEntry, const char *pszAttr,
+                                   const char *pszValue, uint32_t fType);
+
+/**
+ * Unsets (removes) an attribute of a manifest entry if they both exist.
+ *
+ * @returns IPRT status code.
+ * @retval  VWRN_NOT_FOUND if not found.
+ *
+ * @param   hManifest           The manifest handle.
+ * @param   pszEntry            The entry name.
+ * @param   pszAttr             The attribute name.
+ */
+RTDECL(int) RTManifestEntryUnsetAttr(RTMANIFEST hManifest, const char *pszEntry, const char *pszAttr);
+
+/**
+ * Query a manifest entry attribute.
+ *
+ * @returns IPRT status code.
+ * @retval  VERR_BUFFER_OVERFLOW if the value buffer is too small. The @a
+ *          pszValue buffer will not be modified.
+ * @retval  VERR_NOT_FOUND if the entry was not found.
  * @retval  VERR_MANIFEST_ATTR_NOT_FOUND
  * @retval  VERR_MANIFEST_ATTR_TYPE_NOT_FOUND
@@ -185,60 +240,4 @@
  * @param   pfType              Where to return the attribute type value.
  */
-RTDECL(int) RTManifestQueryAttr(RTMANIFEST hManifest, const char *pszAttr, uint32_t fType,
-                                char *pszValue, size_t cbValue, uint32_t *pfType);
-
-/**
- * Sets an attribute of a manifest entry.
- *
- * @returns IPRT status code.
- * @param   hManifest           The manifest handle.
- * @param   pszEntry            The entry name.  This will automatically be
- *                              added if there was no previous call to
- *                              RTManifestEntryAdd for this name.  See
- *                              RTManifestEntryAdd for the entry name rules.
- * @param   pszAttr             The attribute name.  If this already exists,
- *                              its value will be replaced.
- * @param   pszValue            The value string.
- * @param   fType               The attribute type, pass
- *                              RTMANIFEST_ATTR_UNKNOWN if not known.
- */
-RTDECL(int) RTManifestEntrySetAttr(RTMANIFEST hManifest, const char *pszEntry, const char *pszAttr,
-                                   const char *pszValue, uint32_t fType);
-
-/**
- * Unsets (removes) an attribute of a manifest entry if they both exist.
- *
- * @returns IPRT status code.
- * @retval  VWRN_NOT_FOUND if not found.
- *
- * @param   hManifest           The manifest handle.
- * @param   pszEntry            The entry name.
- * @param   pszAttr             The attribute name.
- */
-RTDECL(int) RTManifestEntryUnsetAttr(RTMANIFEST hManifest, const char *pszEntry, const char *pszAttr);
-
-/**
- * Query a manifest entry attribute.
- *
- * @returns IPRT status code.
- * @retval  VERR_BUFFER_OVERFLOW if the value buffer is too small. The @a
- *          pszValue buffer will not be modified.
- * @retval  VERR_NOT_FOUND if the entry was not found.
- * @retval  VERR_MANIFEST_ATTR_NOT_FOUND
- * @retval  VERR_MANIFEST_ATTR_TYPE_NOT_FOUND
- * @retval  VERR_MANIFEST_ATTR_TYPE_MISMATCH
- *
- * @param   hManifest           The manifest handle.
- * @param   pszEntry            The entry name.
- * @param   pszAttr             The attribute name.  If NULL, it will be
- *                              selected by @a fType alone.
- * @param   fType               The attribute types the entry should match. Pass
- *                              Pass RTMANIFEST_ATTR_ANY match any.  If more
- *                              than one is given, the first matching one is
- *                              returned.
- * @param   pszValue            Where to return value.
- * @param   cbValue             The size of the buffer @a pszValue points to.
- * @param   pfType              Where to return the attribute type value.
- */
 RTDECL(int) RTManifestEntryQueryAttr(RTMANIFEST hManifest, const char *pszEntry, const char *pszAttr, uint32_t fType,
                                      char *pszValue, size_t cbValue, uint32_t *pfType);
@@ -492,5 +491,5 @@
  * @param   cbSize               Size of the memory buffer.
  * @param   paTests              Array of file names and digests.
- * @param   cTest                Number of entries in paTests.
+ * @param   cTests               Number of entries in paTests.
  * @param   piFailed             A index to paTests in the
  *                               VERR_MANIFEST_DIGEST_MISMATCH error case
Index: /trunk/include/iprt/mem.h
===================================================================
--- /trunk/include/iprt/mem.h	(revision 57925)
+++ /trunk/include/iprt/mem.h	(revision 57926)
@@ -144,5 +144,4 @@
  * @returns NULL on failure, assertion raised in strict builds.
  * @param   cb      Size in bytes of the memory block to allocated.
- * @param   pszTag  Allocation tag used for statistics and such.
  */
 #define RTMemAlloc(cb)                  RTMemAllocTag((cb), RTMEM_TAG)
@@ -299,5 +298,5 @@
 
 
-/** @def RTR0MemAllocEx and RTR0MemAllocExTag flags.
+/** @name RTR0MemAllocEx and RTR0MemAllocExTag flags.
  * @{ */
 /** The returned memory should be zeroed. */
@@ -369,9 +368,4 @@
  * @param   pv                  What to free, NULL is fine.
  * @param   cb                  The amount of allocated memory.
- * @param   fFlags              The flags specified when allocating the memory.
- *                              Whether the exact flags are requires depends on
- *                              the implementation, but in general, ring-0
- *                              doesn't require anything while ring-3 requires
- *                              RTMEMALLOCEX_FLAGS_EXEC if used.
  */
 RTDECL(void) RTMemFreeEx(void *pv, size_t cb) RT_NO_THROW_PROTO;
@@ -636,4 +630,6 @@
  * @param   cb      Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.
+ *                  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfTmpAlloc(size_t cb, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -646,4 +642,6 @@
  * @param   cb      Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfTmpAllocZ(size_t cb, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -653,4 +651,6 @@
  *
  * @param   pv      Pointer to memory block.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void)    RTMemEfTmpFree(void *pv, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -663,4 +663,6 @@
  * @param   cb      Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfAlloc(size_t cb, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -673,4 +675,6 @@
  * @param   cb      Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfAllocZ(size_t cb, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -683,4 +687,6 @@
  * @param   cbUnaligned Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfAllocVar(size_t cbUnaligned, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -693,4 +699,6 @@
  * @param   cbUnaligned Size in bytes of the memory block to allocate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfAllocZVar(size_t cbUnaligned, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -704,4 +712,6 @@
  * @param   cbNew   The new block size (in bytes).
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *)  RTMemEfRealloc(void *pvOld, size_t cbNew, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -722,4 +732,6 @@
  * @param   cb      The amount of memory to duplicate.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *) RTMemEfDup(const void *pvSrc, size_t cb, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -734,4 +746,6 @@
  * @param   cbExtra The amount of extra memory to allocate and zero.
  * @param   pszTag  Allocation tag used for statistics and such.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void *) RTMemEfDupEx(const void *pvSrc, size_t cbSrc, size_t cbExtra, const char *pszTag, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
@@ -920,5 +934,5 @@
 /**
  * Fenced drop-in replacement for RTMemDupExTag.
- * @copydoc RTMemDupExTag
+ * @copydoc RTMemDupTag
  */
 RTDECL(void *) RTMemEfDupNP(const void *pvSrc, size_t cb, const char *pszTag) RT_NO_THROW_PROTO;
Index: /trunk/include/iprt/memsafer.h
===================================================================
--- /trunk/include/iprt/memsafer.h	(revision 57925)
+++ /trunk/include/iprt/memsafer.h	(revision 57926)
@@ -163,5 +163,5 @@
  * @param   cbNew       The size of the new allocation.
  * @param   ppvNew      Where to return the pointer to the new memory.
- * @param   a_fFlags    Flags for controlling the allocation, see
+ * @param   fFlags      Flags for controlling the allocation, see
  *                      RTMEMSAFER_F_XXX.  It is not permitted to drop saftely
  *                      requirments after the initial allocation.
Index: /trunk/include/iprt/message.h
===================================================================
--- /trunk/include/iprt/message.h	(revision 57925)
+++ /trunk/include/iprt/message.h	(revision 57926)
@@ -84,5 +84,5 @@
  * @param   ...             Format arguments.
  */
-RTDECL(RTEXITCODE) RTMsgErrorExit(RTEXITCODE enmExitcode, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(2, 3);
+RTDECL(RTEXITCODE) RTMsgErrorExit(RTEXITCODE enmExitCode, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(2, 3);
 
 /**
@@ -106,5 +106,5 @@
  * @param   ...             Format arguments.
  */
-RTDECL(int) RTMsgErrorRc(int rc, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(2, 3);
+RTDECL(int) RTMsgErrorRc(int rcRet, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(2, 3);
 
 /**
@@ -117,5 +117,5 @@
  * @param   va              Format arguments.
  */
-RTDECL(int) RTMsgErrorRcV(int rc, const char *pszFormat, va_list va) RT_IPRT_FORMAT_ATTR(2, 0);
+RTDECL(int) RTMsgErrorRcV(int rcRet, const char *pszFormat, va_list va) RT_IPRT_FORMAT_ATTR(2, 0);
 
 /**
Index: /trunk/include/iprt/net.h
===================================================================
--- /trunk/include/iprt/net.h	(revision 57925)
+++ /trunk/include/iprt/net.h	(revision 57926)
@@ -47,6 +47,6 @@
  *          failure.
  *
- * @param   pszValue        The value to convert.
- * @param   pAddr           Where to store the result.
+ * @param   pszAddr         The address string to convert.
+ * @param   pMacAddr        Where to store the result.
  */
 RTDECL(int) RTNetStrToMacAddr(const char *pszAddr, PRTMAC pMacAddr);
Index: /trunk/include/iprt/path.h
===================================================================
--- /trunk/include/iprt/path.h	(revision 57925)
+++ /trunk/include/iprt/path.h	(revision 57926)
@@ -807,5 +807,5 @@
  *          RTPATHSPLIT::cchPath.
  *
- * @param   pParsed             The parser output for @a pszSrcPath.
+ * @param   pSplit              A split path (see RTPathSplit, RTPathSplitA).
  * @param   fFlags              Combination of RTPATH_STR_F_STYLE_XXX.
  *                              Most users will pass 0.
Index: /trunk/include/iprt/process.h
===================================================================
--- /trunk/include/iprt/process.h	(revision 57925)
+++ /trunk/include/iprt/process.h	(revision 57926)
@@ -160,5 +160,5 @@
  * @param   pszAsUser   User to run the process as.  Pass NULL to use the same
  *                      user as the current process.
- *                      Windows: Use user@domain format to specify a domain.
+ *                      Windows: Use user\@domain format to specify a domain.
  * @param   pszPassword Password to use to authenticate @a pszAsUser.  Must be
  *                      NULL wif pszAsUser is NULL.  Whether this is actually
@@ -341,7 +341,7 @@
  *          the process by returning from main().
  *
- * @param   papszArgs       The argument vector of the calling process.
- * @param   pszDaemonized   The daemonized option.  This is appended to the end
- *                          of the parameter list of the daemonized process.
+ * @param   papszArgs           The argument vector of the calling process.
+ * @param   pszDaemonizedOpt    The daemonized option.  This is appended to the
+ *                              end of the parameter list of the daemonized process.
  */
 RTR3DECL(int)   RTProcDaemonize(const char * const *papszArgs, const char *pszDaemonizedOpt);
Index: /trunk/include/iprt/semaphore.h
===================================================================
--- /trunk/include/iprt/semaphore.h	(revision 57925)
+++ /trunk/include/iprt/semaphore.h	(revision 57926)
@@ -215,9 +215,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemEventWaitExDebug(RTSEMEVENT hEventSem, uint32_t fFlags, uint64_t uTimeout,
@@ -390,9 +387,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemEventMultiWaitExDebug(RTSEMEVENTMULTI hEventMultiSem, uint32_t fFlags, uint64_t uTimeout,
@@ -468,6 +462,6 @@
  *
  * @returns iprt status code.
- * @param   phRWSem             Where to store the handle to the newly created
- *                              RW semaphore.
+ * @param   phMutexSem          Where to store the handle to the newly created
+ *                              mutex semaphore.
  * @param   fFlags              Flags, any combination of the
  *                              RTSEMMUTEX_FLAGS_XXX \#defines.
@@ -556,9 +550,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemMutexRequestDebug(RTSEMMUTEX hMutexSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -572,9 +563,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemMutexRequestNoResumeDebug(RTSEMMUTEX hMutexSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -608,9 +596,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemMutexRequestExDebug(RTSEMMUTEX hMutexSem, uint32_t fFlags, uint64_t uTimeout,
@@ -916,9 +901,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)   RTSemRWRequestReadDebug(RTSEMRW hRWSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -936,9 +918,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)   RTSemRWRequestReadNoResumeDebug(RTSEMRW hRWSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -979,9 +958,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)   RTSemRWRequestReadExDebug(RTSEMRW hRWSem, uint32_t fFlags, uint64_t uTimeout,
@@ -1033,9 +1009,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemRWRequestWriteDebug(RTSEMRW hRWSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -1049,9 +1022,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemRWRequestWriteNoResumeDebug(RTSEMRW hRWSem, RTMSINTERVAL cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -1088,9 +1058,6 @@
  * @param   uId                 Some kind of locking location ID.  Typically a
  *                              return address up the stack.  Optional (0).
- * @param   pszFile             The file where the lock is being acquired from.
- *                              Optional.
- * @param   iLine               The line number in that file.  Optional (0).
- * @param   pszFunction         The function where the lock is being acquired
- *                              from.  Optional.
+ * @param   SRC_POS             The source position where call is being made
+ *                              from.  Use RT_SRC_POS when possible.  Optional.
  */
 RTDECL(int)  RTSemRWRequestWriteExDebug(RTSEMRW hRWSem, uint32_t fFlags, uint64_t uTimeout,
Index: /trunk/include/iprt/string.h
===================================================================
--- /trunk/include/iprt/string.h	(revision 57925)
+++ /trunk/include/iprt/string.h	(revision 57926)
@@ -183,5 +183,5 @@
  * this as pointer to a volatile but read-only string.
  */
-#ifndef RTSTR_TAG
+#if !defined(RTSTR_TAG) || defined(DOXYGEN_RUNNING)
 # define RTSTR_TAG      (__FILE__)
 #endif
@@ -729,5 +729,5 @@
  *          may be partially processed.
  * @param   psz            The string to sanitise.
- * @param   puszValidSets  A zero-terminated array of pairs of Unicode points.
+ * @param   puszValidSet   A zero-terminated array of pairs of Unicode points.
  *                         Each pair is the start and end point of a range,
  *                         and the union of these ranges forms the white list.
@@ -929,5 +929,5 @@
  *                      This is undefined on failure.
  */
-RTDECL(int) RTStrCalcLatin1LenEx(const char *psz, size_t cch, size_t *pcwc);
+RTDECL(int) RTStrCalcLatin1LenEx(const char *psz, size_t cch, size_t *pcch);
 
 /**
@@ -1460,8 +1460,12 @@
  * @param   psz         Pointer to the current code point.
  */
-DECLINLINE(char *) RTLatin1PrevCp(const char *psz)
+DECLINLINE(char *) RTLatin1PrevCp(const char *pszStart const char *psz)
 {
-    psz--;
-    return (char *)psz;
+    if ((uintptr_t)psz > (uintptr_t)pszStart)
+    {
+        psz--;
+        return (char *)psz;
+    }
+    return (char *)pszStart;
 }
 
@@ -3480,5 +3484,5 @@
  *          terminated.
  *
- * @param   pszDst              The destination buffer.
+ * @param   pwszDst             The destination buffer.
  * @param   cwcDst              The size of the destination buffer in RTUTF16s.
  * @param   pwszSrc             The source string.  NULL is not OK.
@@ -3494,9 +3498,9 @@
  *          terminated.
  *
- * @param   pszDst              The destination buffer.
+ * @param   pwszDst             The destination buffer.
  * @param   cwcDst              The size of the destination buffer in RTUTF16s.
  * @param   pszSrc              The source string, pure ASCII.  NULL is not OK.
  */
-RTDECL(int) RTUtf16CatAscii(PRTUTF16 pwszDst, size_t cwcDst, const char *pwszSrc);
+RTDECL(int) RTUtf16CatAscii(PRTUTF16 pwszDst, size_t cwcDst, const char *pszSrc);
 
 /**
@@ -3650,5 +3654,5 @@
  *          may be partially processed.
  * @param   pwsz           The string to sanitise.
- * @param   puszValidSets  A zero-terminated array of pairs of Unicode points.
+ * @param   puszValidSet   A zero-terminated array of pairs of Unicode points.
  *                         Each pair is the start and end point of a range,
  *                         and the union of these ranges forms the white list.
Index: /trunk/src/VBox/Runtime/Doxyfile
===================================================================
--- /trunk/src/VBox/Runtime/Doxyfile	(revision 57925)
+++ /trunk/src/VBox/Runtime/Doxyfile	(revision 57926)
@@ -205,4 +205,29 @@
 \
 Implements the callback \link \1 \1 "
+
+# bugref - xTracker bug reference, takes one to four bug numbers.
+ALIASES               += bugref{1}="https://xtracker.innotek.de/index.php?bug=\1"
+ALIASES               += bugref{2}="https://xtracker.innotek.de/index.php?bug=\1, \
+https://xtracker.innotek.de/index.php?bug=\2"
+ALIASES               += bugref{3}="https://xtracker.innotek.de/index.php?bug=\1, \
+https://xtracker.innotek.de/index.php?bug=\2, \
+https://xtracker.innotek.de/index.php?bug=\3"
+ALIASES               += bugref{4}="https://xtracker.innotek.de/index.php?bug=\1, \
+https://xtracker.innotek.de/index.php?bug=\2, \
+https://xtracker.innotek.de/index.php?bug=\3, \
+https://xtracker.innotek.de/index.php?bug=\4"
+
+# ticketref - Track ticket reference, takes one to four ticket numbers.
+ALIASES               += ticketref{1}="http://www.virtualbox.org/ticket/\1"
+ALIASES               += ticketref{2}="http://www.virtualbox.org/ticket/\1, \
+http://www.virtualbox.org/ticket/\2"
+ALIASES               += ticketref{3}="http://www.virtualbox.org/ticket/\1, \
+http://www.virtualbox.org/ticket/\2, \
+http://www.virtualbox.org/ticket/\3"
+ALIASES               += ticketref{4}="http://www.virtualbox.org/ticket/\1, \
+http://www.virtualbox.org/ticket/\2, \
+http://www.virtualbox.org/ticket/\3, \
+http://www.virtualbox.org/ticket/\4"
+
 
 # Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C
@@ -1194,4 +1219,5 @@
     "DECLINLINE(type)=inline type" \
     DECL_FORCE_INLINE(type)=DECLINLINE(type) \
+    DECL_NO_INLINE(type)=type \
     \
     AssertCompile(expr) \
@@ -1203,4 +1229,11 @@
     AssertCompile2MemberOffsets(a,b,c) \
     \
+    RT_SRC_POS=1 \
+    RT_SRC_POS_ARGS=SRC_POS \
+    "RT_SRC_POS_DECL=int SRC_POS" \
+    \
+    RT_IPRT_FORMAT_ATTR(a,b)= \
+    RT_IPRT_FORMAT_ATTR_MAYBE_NULL(a,b)= \
+    RT_NO_THROW_PROTO=
 
 # If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then
@@ -1245,8 +1278,4 @@
     CTXMID \
     OTHERCTXMID \
-    \
-    RT_SRC_POS \
-    RT_SRC_POS_ARGS \
-    RT_SRC_POS_DECL
 
 
Index: /trunk/src/VBox/Runtime/common/asn1/asn1-basics.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/asn1/asn1-basics.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/common/asn1/asn1-basics.cpp	(revision 57926)
@@ -334,11 +334,11 @@
  */
 
-RTDECL(void) RTAsn1VtDelete(PRTASN1CORE pAsn1Core)
-{
-    if (pAsn1Core)
-    {
-        PCRTASN1COREVTABLE pOps = pAsn1Core->pOps;
+RTDECL(void) RTAsn1VtDelete(PRTASN1CORE pThisCore)
+{
+    if (pThisCore)
+    {
+        PCRTASN1COREVTABLE pOps = pThisCore->pOps;
         if (pOps)
-            pOps->pfnDtor(pAsn1Core);
+            pOps->pfnDtor(pThisCore);
     }
 }
@@ -355,11 +355,11 @@
 
 
-static DECLCALLBACK(int) rtAsn1VtDeepEnumDepthFirst(PRTASN1CORE pAsn1Core, const char *pszName, uint32_t uDepth, void *pvUser)
-{
-    AssertReturn(pAsn1Core, VINF_SUCCESS);
-
-    if (pAsn1Core->pOps && pAsn1Core->pOps->pfnEnum)
-    {
-        int rc = pAsn1Core->pOps->pfnEnum(pAsn1Core, rtAsn1VtDeepEnumDepthFirst, uDepth, pvUser);
+static DECLCALLBACK(int) rtAsn1VtDeepEnumDepthFirst(PRTASN1CORE pThisCore, const char *pszName, uint32_t uDepth, void *pvUser)
+{
+    AssertReturn(pThisCore, VINF_SUCCESS);
+
+    if (pThisCore->pOps && pThisCore->pOps->pfnEnum)
+    {
+        int rc = pThisCore->pOps->pfnEnum(pThisCore, rtAsn1VtDeepEnumDepthFirst, uDepth, pvUser);
         if (rc != VINF_SUCCESS)
             return rc;
@@ -367,18 +367,18 @@
 
     RTASN1DEEPENUMCTX *pCtx = (RTASN1DEEPENUMCTX *)pvUser;
-    return pCtx->pfnCallback(pAsn1Core, pszName, uDepth, pCtx->pvUser);
-}
-
-
-static DECLCALLBACK(int) rtAsn1VtDeepEnumDepthLast(PRTASN1CORE pAsn1Core, const char *pszName, uint32_t uDepth, void *pvUser)
-{
-    AssertReturn(pAsn1Core, VINF_SUCCESS);
+    return pCtx->pfnCallback(pThisCore, pszName, uDepth, pCtx->pvUser);
+}
+
+
+static DECLCALLBACK(int) rtAsn1VtDeepEnumDepthLast(PRTASN1CORE pThisCore, const char *pszName, uint32_t uDepth, void *pvUser)
+{
+    AssertReturn(pThisCore, VINF_SUCCESS);
 
     RTASN1DEEPENUMCTX *pCtx = (RTASN1DEEPENUMCTX *)pvUser;
-    int rc = pCtx->pfnCallback(pAsn1Core, pszName, uDepth, pCtx->pvUser);
+    int rc = pCtx->pfnCallback(pThisCore, pszName, uDepth, pCtx->pvUser);
     if (rc == VINF_SUCCESS)
     {
-        if (pAsn1Core->pOps && pAsn1Core->pOps->pfnEnum)
-            rc = pAsn1Core->pOps->pfnEnum(pAsn1Core, rtAsn1VtDeepEnumDepthFirst, uDepth, pvUser);
+        if (pThisCore->pOps && pThisCore->pOps->pfnEnum)
+            rc = pThisCore->pOps->pfnEnum(pThisCore, rtAsn1VtDeepEnumDepthFirst, uDepth, pvUser);
     }
     return rc;
Index: /trunk/src/VBox/Runtime/common/checksum/manifest2.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/checksum/manifest2.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/common/checksum/manifest2.cpp	(revision 57926)
@@ -135,5 +135,5 @@
     const char * const *papszIgnoreEntries;
     /** Name of attributes to ignore. */
-    const char * const *papszIgnoreAttr;
+    const char * const *papszIgnoreAttrs;
     /** Flags governing the comparision. */
     uint32_t            fFlags;
@@ -350,5 +350,5 @@
      * Ignore this entry?
      */
-    char const * const *ppsz = pEquals->papszIgnoreAttr;
+    char const * const *ppsz = pEquals->papszIgnoreAttrs;
     if (ppsz)
     {
@@ -425,5 +425,5 @@
      * Ignore this entry?
      */
-    char const * const *ppsz = pEquals->papszIgnoreAttr;
+    char const * const *ppsz = pEquals->papszIgnoreAttrs;
     if (ppsz)
     {
@@ -571,5 +571,5 @@
 
 RTDECL(int) RTManifestEqualsEx(RTMANIFEST hManifest1, RTMANIFEST hManifest2, const char * const *papszIgnoreEntries,
-                               const char * const *papszIgnoreAttr, uint32_t fFlags, char *pszError, size_t cbError)
+                               const char * const *papszIgnoreAttrs, uint32_t fFlags, char *pszError, size_t cbError)
 {
     /*
@@ -614,5 +614,5 @@
     Equals.fFlags               = fFlags;
     Equals.papszIgnoreEntries   = papszIgnoreEntries;
-    Equals.papszIgnoreAttr      = papszIgnoreAttr;
+    Equals.papszIgnoreAttrs     = papszIgnoreAttrs;
     Equals.pszError             = pszError;
     Equals.cbError              = cbError;
Index: /trunk/src/VBox/Runtime/common/err/RTErrConvertFromErrno.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/err/RTErrConvertFromErrno.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/common/err/RTErrConvertFromErrno.cpp	(revision 57926)
@@ -120,5 +120,5 @@
 #endif
 #ifdef ENFILE
-        case ENFILE:            return VERR_TOO_MANY_OPEN_FILES; /**@Todo fix duplicate error */
+        case ENFILE:            return VERR_TOO_MANY_OPEN_FILES; /** @todo fix duplicate error */
 #endif
 #ifdef EMFILE
Index: /trunk/src/VBox/Runtime/common/err/errmsg.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/err/errmsg.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/common/err/errmsg.cpp	(revision 57926)
@@ -46,5 +46,5 @@
 static const RTSTATUSMSG  g_aStatusMsgs[] =
 {
-#ifndef IPRT_NO_ERROR_DATA
+#if !defined(IPRT_NO_ERROR_DATA) && !defined(DOXYGEN_RUNNING)
 # include "errmsgdata.h"
 #else
Index: /trunk/src/VBox/Runtime/common/err/errmsgxpcom.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/err/errmsgxpcom.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/common/err/errmsgxpcom.cpp	(revision 57926)
@@ -107,5 +107,5 @@
     MY_ERR("NS_SUCCESS_FILE_DIRECTORY_EMPTY",       "NS_SUCCESS_FILE_DIRECTORY_EMPTY",              UINT32_C(0x00520001)),
 
-#if defined(VBOX) && !defined(IN_GUEST)
+#if defined(VBOX) && !defined(IN_GUEST) && !defined(DOXYGEN_RUNNING)
 # include "errmsgvboxcomdata.h"
 #endif
Index: /trunk/src/VBox/Runtime/r0drv/solaris/semeventwait-r0drv-solaris.h
===================================================================
--- /trunk/src/VBox/Runtime/r0drv/solaris/semeventwait-r0drv-solaris.h	(revision 57925)
+++ /trunk/src/VBox/Runtime/r0drv/solaris/semeventwait-r0drv-solaris.h	(revision 57926)
@@ -101,5 +101,4 @@
  * @param   fFlags              The wait flags.
  * @param   uTimeout            The timeout.
- * @param   pWaitQueue          The wait queue head.
  */
 DECLINLINE(int) rtR0SemSolWaitInit(PRTR0SEMSOLWAIT pWait, uint32_t fFlags, uint64_t uTimeout)
Index: /trunk/src/VBox/Runtime/r3/init.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/init.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/r3/init.cpp	(revision 57926)
@@ -369,5 +369,5 @@
  * rtR3Init worker.
  */
-static int rtR3InitBody(uint32_t fFlags, int cArgs, char ***papszArgs, const char *pszProgramPath)
+static int rtR3InitBody(uint32_t fFlags, int cArgs, char ***ppapszArgs, const char *pszProgramPath)
 {
     /*
@@ -448,5 +448,5 @@
     AssertLogRelMsgRCReturn(rc, ("Failed to get executable directory path, rc=%Rrc!\n", rc), rc);
 
-    rc = rtR3InitArgv(fFlags, cArgs, papszArgs);
+    rc = rtR3InitArgv(fFlags, cArgs, ppapszArgs);
     AssertLogRelMsgRCReturn(rc, ("Failed to convert the arguments, rc=%Rrc!\n", rc), rc);
 
@@ -550,5 +550,5 @@
  *                          out ourselves.
  */
-static int rtR3Init(uint32_t fFlags, int cArgs, char ***papszArgs, const char *pszProgramPath)
+static int rtR3Init(uint32_t fFlags, int cArgs, char ***ppapszArgs, const char *pszProgramPath)
 {
     /* no entry log flow, because prefixes and thread may freak out. */
@@ -590,5 +590,5 @@
             rc = rtR3InitProgramPath(pszProgramPath);
         if (RT_SUCCESS(rc))
-            rc = rtR3InitArgv(fFlags, cArgs, papszArgs);
+            rc = rtR3InitArgv(fFlags, cArgs, ppapszArgs);
         return rc;
     }
@@ -598,5 +598,5 @@
      * Do the initialization.
      */
-    int rc = rtR3InitBody(fFlags, cArgs, papszArgs, pszProgramPath);
+    int rc = rtR3InitBody(fFlags, cArgs, ppapszArgs, pszProgramPath);
     if (RT_FAILURE(rc))
     {
@@ -614,8 +614,8 @@
 
 
-RTR3DECL(int) RTR3InitExe(int cArgs, char ***papszArgs, uint32_t fFlags)
+RTR3DECL(int) RTR3InitExe(int cArgs, char ***ppapszArgs, uint32_t fFlags)
 {
     Assert(!(fFlags & RTR3INIT_FLAGS_DLL));
-    return rtR3Init(fFlags, cArgs, papszArgs, NULL);
+    return rtR3Init(fFlags, cArgs, ppapszArgs, NULL);
 }
 
@@ -635,8 +635,8 @@
 
 
-RTR3DECL(int) RTR3InitEx(uint32_t iVersion, uint32_t fFlags, int cArgs, char ***papszArgs, const char *pszProgramPath)
+RTR3DECL(int) RTR3InitEx(uint32_t iVersion, uint32_t fFlags, int cArgs, char ***ppapszArgs, const char *pszProgramPath)
 {
     AssertReturn(iVersion == RTR3INIT_VER_CUR, VERR_NOT_SUPPORTED);
-    return rtR3Init(fFlags, cArgs, papszArgs, pszProgramPath);
+    return rtR3Init(fFlags, cArgs, ppapszArgs, pszProgramPath);
 }
 
Index: /trunk/src/VBox/Runtime/r3/isofs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/isofs.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/r3/isofs.cpp	(revision 57926)
@@ -525,10 +525,9 @@
 
 
-RTR3DECL(int) RTIsoFsGetFileInfo(PRTISOFSFILE pFile, const char *pszPath,
-                                 uint32_t *pcbOffset, size_t *pcbLength)
+RTR3DECL(int) RTIsoFsGetFileInfo(PRTISOFSFILE pFile, const char *pszPath, uint32_t *poffInIso, size_t *pcbLength)
 {
     AssertPtrReturn(pFile, VERR_INVALID_PARAMETER);
     AssertPtrReturn(pszPath, VERR_INVALID_PARAMETER);
-    AssertPtrReturn(pcbOffset, VERR_INVALID_PARAMETER);
+    AssertPtrReturn(poffInIso, VERR_INVALID_PARAMETER);
 
     PRTISOFSDIRRECORD pDirRecord;
@@ -545,5 +544,5 @@
         if (RT_SUCCESS(rc))
         {
-            *pcbOffset = pFileRecord->extent_location * RTISOFS_SECTOR_SIZE;
+            *poffInIso = pFileRecord->extent_location * RTISOFS_SECTOR_SIZE;
             *pcbLength = pFileRecord->extent_data_length;
             rtIsoFsFreeDirectoryRecord(pFileRecord);
@@ -555,14 +554,13 @@
 
 
-RTR3DECL(int) RTIsoFsExtractFile(PRTISOFSFILE pFile, const char *pszSource,
-                                 const char *pszDest)
-{
-    AssertPtrReturn(pFile, VERR_INVALID_PARAMETER);
-    AssertPtrReturn(pszSource, VERR_INVALID_PARAMETER);
-    AssertPtrReturn(pszDest, VERR_INVALID_PARAMETER);
+RTR3DECL(int) RTIsoFsExtractFile(PRTISOFSFILE pFile, const char *pszSrcPath, const char *pszDstPath)
+{
+    AssertPtrReturn(pFile, VERR_INVALID_PARAMETER);
+    AssertPtrReturn(pszSrcPath, VERR_INVALID_PARAMETER);
+    AssertPtrReturn(pszDstPath, VERR_INVALID_PARAMETER);
 
     uint32_t cbOffset;
     size_t cbLength;
-    int rc = RTIsoFsGetFileInfo(pFile, pszSource, &cbOffset, &cbLength);
+    int rc = RTIsoFsGetFileInfo(pFile, pszSrcPath, &cbOffset, &cbLength);
     if (RT_SUCCESS(rc))
     {
@@ -571,5 +569,5 @@
         {
             RTFILE fileDest;
-            rc = RTFileOpen(&fileDest, pszDest, RTFILE_O_CREATE | RTFILE_O_WRITE | RTFILE_O_DENY_WRITE);
+            rc = RTFileOpen(&fileDest, pszDstPath, RTFILE_O_CREATE | RTFILE_O_WRITE | RTFILE_O_DENY_WRITE);
             if (RT_SUCCESS(rc))
             {
Index: /trunk/src/VBox/Runtime/r3/nt/internal-r3-nt.h
===================================================================
--- /trunk/src/VBox/Runtime/r3/nt/internal-r3-nt.h	(revision 57925)
+++ /trunk/src/VBox/Runtime/r3/nt/internal-r3-nt.h	(revision 57926)
@@ -49,5 +49,5 @@
  * @returns @c true if equal, @c false if not.
  * @param   pwsz1               The first string.
- * @param   cb1                 The length of the first string, in bytes.
+ * @param   cch1                The length of the first string, in bytes.
  * @param   psz2                The second string.
  * @param   cch2                The length of the second string.
Index: /trunk/src/VBox/Runtime/win/errmsgwin.cpp
===================================================================
--- /trunk/src/VBox/Runtime/win/errmsgwin.cpp	(revision 57925)
+++ /trunk/src/VBox/Runtime/win/errmsgwin.cpp	(revision 57926)
@@ -45,5 +45,5 @@
 static const RTWINERRMSG  g_aStatusMsgs[] =
 {
-#ifndef IPRT_NO_ERROR_DATA
+#if !defined(IPRT_NO_ERROR_DATA) && !defined(DOXYGEN_RUNNING)
 # include "errmsgcomdata.h"
 # if defined(VBOX) && !defined(IN_GUEST)

Index: /trunk/include/iprt/getopt.h
===================================================================
--- /trunk/include/iprt/getopt.h	(revision 57925)
+++ /trunk/include/iprt/getopt.h	(revision 57926)
@@ -416,5 +416,5 @@
  * @param   papszArgv       Argument vector.  NULL is fine.
  */
-RTDECL(void) RTGetOptArgvFree(char **paArgv);
+RTDECL(void) RTGetOptArgvFree(char **papszArgv);
 
 /**
@@ -430,5 +430,5 @@
  * @param   ppszCmdLine     Where to return the command line string.  This must
  *                          be freed by calling RTStrFree.
  * @param   papszArgs       The argument vector to convert.
  * @param   fFlags          A combination of the RTGETOPTARGV_CNV_XXX flags.
  */
@@ -430,5 +430,5 @@
  * @param   ppszCmdLine     Where to return the command line string.  This must
  *                          be freed by calling RTStrFree.
- * @param   papszArgs       The argument vector to convert.
+ * @param   papszArgv       The argument vector to convert.
  * @param   fFlags          A combination of the RTGETOPTARGV_CNV_XXX flags.
  */
Index: /trunk/include/iprt/isofs.h
===================================================================
--- /trunk/include/iprt/isofs.h	(revision 57925)
+++ /trunk/include/iprt/isofs.h	(revision 57926)
@@ -194,4 +194,5 @@
  * Retrieves the offset + length (both in bytes) of a given file
  * stored in the ISO.
+ *
  * @note    According to the standard, a file cannot be larger than 2^32-1 bytes.
  *          Therefore using size_t / uint32_t is not a problem.
@@ -200,9 +201,9 @@
  * @param   pFile       Pointer to open ISO file returned by RTIsoFsOpen().
  * @param   pszPath     Path of file within the ISO to retrieve information for.
  * @param   pcbOffset   Pointer to store the file's absolute offset within the ISO.
  * @param   pcbLength   Pointer to store the file's size.
  */
-RTR3DECL(int) RTIsoFsGetFileInfo(PRTISOFSFILE pFile, const char *pszPath,
-                                 uint32_t *pcbOffset, size_t *pcbLength);
+RTR3DECL(int) RTIsoFsGetFileInfo(PRTISOFSFILE pFile, const char *pszPath, uint32_t *poffInIso, size_t *pcbLength);
 
 /**
@@ -211,9 +212,9 @@
  * @return  IPRT status code.
  * @param   pFile       Pointer to open ISO file returned by RTIsoFsOpen().
- * @param   pszPath     Path of file within the ISO to extract.
- * @param   pszDest     Where to store the extracted file.
- */
-RTR3DECL(int) RTIsoFsExtractFile(PRTISOFSFILE pFile, const char *pszSource,
-                                 const char *pszDest);
+ * @param   pszSrcPath  Path of file within the ISO to extract.
+ * @param   pszDstPath  Where to store the extracted file.
+ */
+RTR3DECL(int) RTIsoFsExtractFile(PRTISOFSFILE pFile, const char *pszSrcPath, const char *pszDstPath);
+
 #endif /* IN_RING3 */
 
@@ -200,9 +201,9 @@
  * @param   pFile       Pointer to open ISO file returned by RTIsoFsOpen().
  * @param   pszPath     Path of file within the ISO to retrieve information for.
- * @param   pcbOffset   Pointer to store the file's absolute offset within the ISO.
+ * @param   poffInIso   Wheter to store the file's absolute offset within the
+ *                      ISO.
  * @param   pcbLength   Pointer to store the file's size.
  */
Index: /trunk/include/iprt/sha.h
===================================================================
--- /trunk/include/iprt/sha.h	(revision 57925)
+++ /trunk/include/iprt/sha.h	(revision 57926)
@@ -63,8 +63,8 @@
  * @param   pvBuf       Pointer to the data.
  * @param   cbBuf       The amount of data (in bytes).
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha1(const void *pvBuf, size_t cbBuf, uint8_t pabDigest[RTSHA1_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha1(const void *pvBuf, size_t cbBuf, uint8_t pabHash[RTSHA1_HASH_SIZE]);
 
 /**
@@ -77,5 +77,5 @@
  *                      caller's buffer.)
  */
-RTDECL(bool) RTSha1Check(const void *pvBuf, size_t cbBuf, uint8_t const pabDigest[RTSHA1_HASH_SIZE]);
+RTDECL(bool) RTSha1Check(const void *pvBuf, size_t cbBuf, uint8_t const pabHash[RTSHA1_HASH_SIZE]);
 
 /**
@@ -99,8 +99,8 @@
  *
  * @param   pCtx        Pointer to the SHA-1 context.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha1Final(PRTSHA1CONTEXT pCtx, uint8_t pabDigest[RTSHA1_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha1Final(PRTSHA1CONTEXT pCtx, uint8_t pabHash[RTSHA1_HASH_SIZE]);
 
 /**
@@ -109,10 +109,10 @@
  * @returns IPRT status code.
  *
  * @param   pabDigest   The binary digest returned by RTSha1Final or RTSha1.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
  *                      RTSHA1_DIGEST_LEN + 1 bytes.
  */
-RTDECL(int) RTSha1ToString(uint8_t const pabDigest[RTSHA1_HASH_SIZE], char *pszDigest, size_t cchDigest);
+RTDECL(int) RTSha1ToString(uint8_t const pabHash[RTSHA1_HASH_SIZE], char *pszDigest, size_t cchDigest);
 
 /**
@@ -123,8 +123,8 @@
  * @param   pszDigest   The stringified digest. Leading and trailing spaces are
  *                      ignored.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(int) RTSha1FromString(char const *pszDigest, uint8_t pabDigest[RTSHA1_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(int) RTSha1FromString(char const *pszDigest, uint8_t pabHash[RTSHA1_HASH_SIZE]);
 
 /**
@@ -182,8 +182,8 @@
  * @param   pvBuf       Pointer to the data.
  * @param   cbBuf       The amount of data (in bytes).
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha256(const void *pvBuf, size_t cbBuf, uint8_t pabDigest[RTSHA256_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha256(const void *pvBuf, size_t cbBuf, uint8_t pabHash[RTSHA256_HASH_SIZE]);
 
 /**
@@ -196,5 +196,5 @@
  *                      caller's buffer.)
  */
-RTDECL(bool) RTSha256Check(const void *pvBuf, size_t cbBuf, uint8_t const pabDigest[RTSHA256_HASH_SIZE]);
+RTDECL(bool) RTSha256Check(const void *pvBuf, size_t cbBuf, uint8_t const pabHash[RTSHA256_HASH_SIZE]);
 
 /**
@@ -218,8 +218,8 @@
  *
  * @param   pCtx        Pointer to the SHA-256 context.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha256Final(PRTSHA256CONTEXT pCtx, uint8_t pabDigest[RTSHA256_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha256Final(PRTSHA256CONTEXT pCtx, uint8_t pabHash[RTSHA256_HASH_SIZE]);
 
 /**
@@ -228,10 +228,10 @@
  * @returns IPRT status code.
  *
  * @param   pabDigest   The binary digest returned by RTSha256Final or RTSha256.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
  *                      RTSHA256_DIGEST_LEN + 1 bytes.
  */
-RTDECL(int) RTSha256ToString(uint8_t const pabDigest[RTSHA256_HASH_SIZE], char *pszDigest, size_t cchDigest);
+RTDECL(int) RTSha256ToString(uint8_t const pabHash[RTSHA256_HASH_SIZE], char *pszDigest, size_t cchDigest);
 
 /**
@@ -242,8 +242,8 @@
  * @param   pszDigest   The stringified digest. Leading and trailing spaces are
  *                      ignored.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(int) RTSha256FromString(char const *pszDigest, uint8_t pabDigest[RTSHA256_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(int) RTSha256FromString(char const *pszDigest, uint8_t pabHash[RTSHA256_HASH_SIZE]);
 
 /**
@@ -291,8 +291,8 @@
  * @param   pvBuf       Pointer to the data.
  * @param   cbBuf       The amount of data (in bytes).
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha224(const void *pvBuf, size_t cbBuf, uint8_t pabDigest[RTSHA224_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha224(const void *pvBuf, size_t cbBuf, uint8_t pabHash[RTSHA224_HASH_SIZE]);
 
 /**
@@ -305,5 +305,5 @@
  *                      caller's buffer.)
  */
-RTDECL(bool) RTSha224Check(const void *pvBuf, size_t cbBuf, uint8_t const pabDigest[RTSHA224_HASH_SIZE]);
+RTDECL(bool) RTSha224Check(const void *pvBuf, size_t cbBuf, uint8_t const pabHash[RTSHA224_HASH_SIZE]);
 
 /**
@@ -327,8 +327,8 @@
  *
  * @param   pCtx        Pointer to the SHA-224 context.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha224Final(PRTSHA224CONTEXT pCtx, uint8_t pabDigest[RTSHA224_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha224Final(PRTSHA224CONTEXT pCtx, uint8_t pabHash[RTSHA224_HASH_SIZE]);
 
 /**
@@ -337,10 +337,10 @@
  * @returns IPRT status code.
  *
  * @param   pabDigest   The binary digest returned by RTSha224Final or RTSha224.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
  *                      RTSHA224_DIGEST_LEN + 1 bytes.
  */
-RTDECL(int) RTSha224ToString(uint8_t const pabDigest[RTSHA224_HASH_SIZE], char *pszDigest, size_t cchDigest);
+RTDECL(int) RTSha224ToString(uint8_t const pabHash[RTSHA224_HASH_SIZE], char *pszDigest, size_t cchDigest);
 
 /**
@@ -351,8 +351,8 @@
  * @param   pszDigest   The stringified digest. Leading and trailing spaces are
  *                      ignored.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(int) RTSha224FromString(char const *pszDigest, uint8_t pabDigest[RTSHA224_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(int) RTSha224FromString(char const *pszDigest, uint8_t pabHash[RTSHA224_HASH_SIZE]);
 
 /**
@@ -410,8 +410,8 @@
  * @param   pvBuf       Pointer to the data.
  * @param   cbBuf       The amount of data (in bytes).
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha512(const void *pvBuf, size_t cbBuf, uint8_t pabDigest[RTSHA512_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha512(const void *pvBuf, size_t cbBuf, uint8_t pabHash[RTSHA512_HASH_SIZE]);
 
 /**
@@ -424,5 +424,5 @@
  *                      caller's buffer.)
  */
-RTDECL(bool) RTSha512Check(const void *pvBuf, size_t cbBuf, uint8_t const pabDigest[RTSHA512_HASH_SIZE]);
+RTDECL(bool) RTSha512Check(const void *pvBuf, size_t cbBuf, uint8_t const pabHash[RTSHA512_HASH_SIZE]);
 
 /**
@@ -446,8 +446,8 @@
  *
  * @param   pCtx        Pointer to the SHA-512 context.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(void) RTSha512Final(PRTSHA512CONTEXT pCtx, uint8_t pabDigest[RTSHA512_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(void) RTSha512Final(PRTSHA512CONTEXT pCtx, uint8_t pabHash[RTSHA512_HASH_SIZE]);
 
 /**
@@ -456,10 +456,10 @@
  * @returns IPRT status code.
  *
  * @param   pabDigest   The binary digest returned by RTSha512Final or RTSha512.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
  *                      RTSHA512_DIGEST_LEN + 1 bytes.
  */
-RTDECL(int) RTSha512ToString(uint8_t const pabDigest[RTSHA512_HASH_SIZE], char *pszDigest, size_t cchDigest);
+RTDECL(int) RTSha512ToString(uint8_t const pabHash[RTSHA512_HASH_SIZE], char *pszDigest, size_t cchDigest);
 
 /**
@@ -470,8 +470,8 @@
  * @param   pszDigest   The stringified digest. Leading and trailing spaces are
  *                      ignored.
- * @param   pabDigest   Where to store the hash. (What is passed is a pointer to
- *                      the caller's buffer.)
- */
-RTDECL(int) RTSha512FromString(char const *pszDigest, uint8_t pabDigest[RTSHA512_HASH_SIZE]);
+ * @param   pabHash     Where to store the hash. (What is passed is a pointer to
+ *                      the caller's buffer.)
+ */
+RTDECL(int) RTSha512FromString(char const *pszDigest, uint8_t pabHash[RTSHA512_HASH_SIZE]);
 
 
@@ -481,11 +481,11 @@
     typedef RTSHA512CONTEXT RT_CONCAT3(RTSHA,a_UName,CONTEXT); \
     typedef RTSHA512CONTEXT *RT_CONCAT3(PRTSHA,a_UName,CONTEXT); \
-    RTDECL(void) RT_CONCAT(RTSha,a_Name)(const void *pvBuf, size_t cbBuf, uint8_t pabDigest[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
-    RTDECL(bool) RT_CONCAT3(RTSha,a_Name,Check)(const void *pvBuf, size_t cbBuf, uint8_t const pabDigest[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
+    RTDECL(void) RT_CONCAT(RTSha,a_Name)(const void *pvBuf, size_t cbBuf, uint8_t pabHash[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
+    RTDECL(bool) RT_CONCAT3(RTSha,a_Name,Check)(const void *pvBuf, size_t cbBuf, uint8_t const pabHash[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
     RTDECL(void) RT_CONCAT3(RTSha,a_Name,Init)(RT_CONCAT3(PRTSHA,a_UName,CONTEXT) pCtx); \
     RTDECL(void) RT_CONCAT3(RTSha,a_Name,Update)(RT_CONCAT3(PRTSHA,a_UName,CONTEXT) pCtx, const void *pvBuf, size_t cbBuf); \
-    RTDECL(void) RT_CONCAT3(RTSha,a_Name,Final)(RT_CONCAT3(PRTSHA,a_UName,CONTEXT) pCtx, uint8_t pabDigest[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
-    RTDECL(int)  RT_CONCAT3(RTSha,a_Name,ToString)(uint8_t const pabDigest[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)], char *pszDigest, size_t cchDigest); \
-    RTDECL(int)  RT_CONCAT3(RTSha,a_Name,FromString)(char const *pszDigest, uint8_t pabDigest[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)])
+    RTDECL(void) RT_CONCAT3(RTSha,a_Name,Final)(RT_CONCAT3(PRTSHA,a_UName,CONTEXT) pCtx, uint8_t pabHash[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)]); \
+    RTDECL(int)  RT_CONCAT3(RTSha,a_Name,ToString)(uint8_t const pabHash[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)], char *pszDigest, size_t cchDigest); \
+    RTDECL(int)  RT_CONCAT3(RTSha,a_Name,FromString)(char const *pszDigest, uint8_t pabHash[RT_CONCAT3(RTSHA,a_UName,_HASH_SIZE)])
 
 
@@ -109,10 +109,10 @@
  * @returns IPRT status code.
  *
- * @param   pabDigest   The binary digest returned by RTSha1Final or RTSha1.
+ * @param   pabHash     The binary digest returned by RTSha1Final or RTSha1.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
@@ -228,10 +228,10 @@
  * @returns IPRT status code.
  *
- * @param   pabDigest   The binary digest returned by RTSha256Final or RTSha256.
+ * @param   pabHash     The binary digest returned by RTSha256Final or RTSha256.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
@@ -337,10 +337,10 @@
  * @returns IPRT status code.
  *
- * @param   pabDigest   The binary digest returned by RTSha224Final or RTSha224.
+ * @param   pabHash     The binary digest returned by RTSha224Final or RTSha224.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
@@ -456,10 +456,10 @@
  * @returns IPRT status code.
  *
- * @param   pabDigest   The binary digest returned by RTSha512Final or RTSha512.
+ * @param   pabHash     The binary digest returned by RTSha512Final or RTSha512.
  * @param   pszDigest   Where to return the stringified digest.
  * @param   cchDigest   The size of the output buffer. Should be at least
Index: /trunk/include/iprt/socket.h
===================================================================
--- /trunk/include/iprt/socket.h	(revision 57925)
+++ /trunk/include/iprt/socket.h	(revision 57926)
@@ -228,12 +228,11 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
- * @param   fEvents     Event mask to wait for.
- * @param   pfEvents    Where to store the event mask on return.
- * @param   cMillies    Number of milliseconds to wait for the socket.
- *                      Use RT_INDEFINITE_WAIT to wait for ever.
- */
-RTR3DECL(int)  RTSocketSelectOneEx(RTSOCKET Sock, uint32_t fEvents, uint32_t *pfEvents,
-                                   RTMSINTERVAL cMillies);
+ * @param   hSocket         The Socket handle.
+ * @param   fEvents         Event mask to wait for.
+ * @param   pfEvents        Where to store the event mask on return.
+ * @param   cMillies        Number of milliseconds to wait for the socket.  Use
+ *                          RT_INDEFINITE_WAIT to wait for ever.
+ */
+RTR3DECL(int)  RTSocketSelectOneEx(RTSOCKET hSocket, uint32_t fEvents, uint32_t *pfEvents, RTMSINTERVAL cMillies);
 
 /**
@@ -241,7 +240,7 @@
  *
  * @returns IPRT status code.
- * @param   hSocket             The socket handle.
- * @param   fRead               Whether to shutdown our read direction.
- * @param   fWrite              Whether to shutdown our write direction.
+ * @param   hSocket         The socket handle.
+ * @param   fRead           Whether to shutdown our read direction.
+ * @param   fWrite          Whether to shutdown our write direction.
  */
 RTDECL(int) RTSocketShutdown(RTSOCKET hSocket, bool fRead, bool fWrite);
@@ -251,5 +250,5 @@
  *
  * @returns IPRT status code.
  * @param   Sock            Socket descriptor.
  * @param   pAddr           Where to store the local address on success.
  */
@@ -260,5 +259,5 @@
  *
  * @returns IPRT status code.
  * @param   Sock            Socket descriptor.
  * @param   pAddr           Where to store the peer address on success.
  */
@@ -349,9 +348,9 @@
  * @returns iprt status code.
  *
  * @param   Sock        Socket descriptor.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  * @param   pcbWritten  Number of bytes written.
  */
-RTR3DECL(int)  RTSocketSgWriteNB(RTSOCKET Sock, PCRTSGBUF pSgBuf, size_t *pcbWritten);
+RTR3DECL(int)  RTSocketSgWriteNB(RTSOCKET hSocket, PCRTSGBUF pSgBuf, size_t *pcbWritten);
 
 
@@ -251,5 +250,5 @@
  *
  * @returns IPRT status code.
- * @param   Sock            Socket descriptor.
+ * @param   hSocket         The Socket handle.
  * @param   pAddr           Where to store the local address on success.
  */
@@ -260,5 +259,5 @@
  *
  * @returns IPRT status code.
- * @param   Sock            Socket descriptor.
+ * @param   hSocket         The Socket handle.
  * @param   pAddr           Where to store the peer address on success.
  */
@@ -349,9 +348,9 @@
  * @returns iprt status code.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     The Socket handle.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  * @param   pcbWritten  Number of bytes written.